:mod:`ginsfsm.protocols.wsgi`
=============================

.. automodule:: ginsfsm.protocols.wsgi

Are you tired of the tyranny of monolithic wsgi function? break the yoke.
Send the http response when you want.

Gojs involved:

.. image:: wsgi-server.png

.. automodule:: ginsfsm.protocols.wsgi.server.c_wsgi_server
